==> Paws-0.02.tar.gz: Paws-0.02/lib/Paws/CodeDeploy/GetApplicationRevision.pm <==

package Paws::CodeDeploy::GetApplicationRevision {
  use Moose;
  has applicationName => (is => 'ro', isa => 'Str', required => 1);
  has revision => (is => 'ro', isa => 'Paws::CodeDeploy::RevisionLocation', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetApplicationRevision');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::CodeDeploy::GetApplicationRevisionOutput');
  class_has _result_key => (isa => 'Str', is => 'ro');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::CodeDeploy::GetApplicationRevision - Arguments for method GetApplicationRevision on Paws::CodeDeploy

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetApplicationRevision on the 
AWS CodeDeploy service. Use the attributes of this class
as arguments to method GetApplicationRevision.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to GetApplicationRevision.

As an example:

  $service_obj->GetApplicationRevision(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> applicationName => Str

  

The name of the application that corresponds to the revision.










=head2 B<REQUIRED> revision => Paws::CodeDeploy::RevisionLocation

  

Information about the application revision to get, including the
revision's type and its location.












=head1 SEE ALSO

This class forms part of L<Paws>, and documents parameters for GetApplicationRevision in Paws::CodeDeploy

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.03.tar.gz: Paws-0.03/lib/Paws/CodeDeploy/GetApplicationRevision.pm <==

package Paws::CodeDeploy::GetApplicationRevision {
  use Moose;
  has applicationName => (is => 'ro', isa => 'Str', required => 1);
  has revision => (is => 'ro', isa => 'Paws::CodeDeploy::RevisionLocation', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetApplicationRevision');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::CodeDeploy::GetApplicationRevisionOutput');
  class_has _result_key => (isa => 'Str', is => 'ro');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::CodeDeploy::GetApplicationRevision - Arguments for method GetApplicationRevision on Paws::CodeDeploy

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetApplicationRevision on the 
AWS CodeDeploy service. Use the attributes of this class
as arguments to method GetApplicationRevision.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to GetApplicationRevision.

As an example:

  $service_obj->GetApplicationRevision(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> applicationName => Str

  

The name of the application that corresponds to the revision.










=head2 B<REQUIRED> revision => Paws::CodeDeploy::RevisionLocation

  

Information about the application revision to get, including the
revision's type and its location.












=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetApplicationRevision in L<Paws::CodeDeploy>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
